==> bootpay_webview_flutter-4.0.2.tar.gz: test/webview_cookie_manager_test.dart <==
// Copyright 2013 The Flutter Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/annotations.dart';
import 'package:mockito/mockito.dart';
import 'package:bootpay_webview_flutter/webview_flutter.dart';
import 'package:bootpay_webview_flutter_platform_interface/bootpay_webview_flutter_platform_interface.dart';

import 'webview_cookie_manager_test.mocks.dart';

@GenerateMocks(<Type>[PlatformWebViewCookieManager])
void main() {
  group('WebViewCookieManager', () {
    test('clearCookies', () async {
      final MockPlatformWebViewCookieManager mockPlatformWebViewCookieManager =
          MockPlatformWebViewCookieManager();
      when(mockPlatformWebViewCookieManager.clearCookies()).thenAnswer(
        (_) => Future<bool>.value(false),
      );

      final WebViewCookieManager cookieManager =
          WebViewCookieManager.fromPlatform(
        mockPlatformWebViewCookieManager,
      );

      await expectLater(cookieManager.clearCookies(), completion(false));
    });

    test('setCookie', () async {
      final MockPlatformWebViewCookieManager mockPlatformWebViewCookieManager =
          MockPlatformWebViewCookieManager();

      final WebViewCookieManager cookieManager =
          WebViewCookieManager.fromPlatform(
        mockPlatformWebViewCookieManager,
      );

      const WebViewCookie cookie = WebViewCookie(
        name: 'name',
        value: 'value',
        domain: 'domain',
      );

      await cookieManager.setCookie(cookie);

      final WebViewCookie capturedCookie = verify(
        mockPlatformWebViewCookieManager.setCookie(captureAny),
      ).captured.single as WebViewCookie;
      expect(capturedCookie, cookie);
    });
  });
}

==> bootpay_webview_flutter-4.2.3.tar.gz: test/webview_cookie_manager_test.dart <==
// Copyright 2013 The Flutter Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/annotations.dart';
import 'package:mockito/mockito.dart';
import 'package:bootpay_webview_flutter/bootpay_webview_flutter.dart';
import 'package:bootpay_webview_flutter_platform_interface/bootpay_webview_flutter_platform_interface.dart';

import 'webview_cookie_manager_test.mocks.dart';

@GenerateMocks(<Type>[PlatformWebViewCookieManager])
void main() {
  group('WebViewCookieManager', () {
    test('clearCookies', () async {
      final MockPlatformWebViewCookieManager mockPlatformWebViewCookieManager =
          MockPlatformWebViewCookieManager();
      when(mockPlatformWebViewCookieManager.clearCookies()).thenAnswer(
        (_) => Future<bool>.value(false),
      );

      final WebViewCookieManager cookieManager =
          WebViewCookieManager.fromPlatform(
        mockPlatformWebViewCookieManager,
      );

      await expectLater(cookieManager.clearCookies(), completion(false));
    });

    test('setCookie', () async {
      final MockPlatformWebViewCookieManager mockPlatformWebViewCookieManager =
          MockPlatformWebViewCookieManager();

      final WebViewCookieManager cookieManager =
          WebViewCookieManager.fromPlatform(
        mockPlatformWebViewCookieManager,
      );

      const WebViewCookie cookie = WebViewCookie(
        name: 'name',
        value: 'value',
        domain: 'domain',
      );

      await cookieManager.setCookie(cookie);

      final WebViewCookie capturedCookie = verify(
        mockPlatformWebViewCookieManager.setCookie(captureAny),
      ).captured.single as WebViewCookie;
      expect(capturedCookie, cookie);
    });
  });
}
